
.. _roc-index:

Numba for AMD ROC GPUs
======================

.. toctree::

   overview.rst
   kernels.rst
   memory.rst
   device-functions.rst
   intrinsics.rst
   device-management.rst
   ufunc.rst
   examples.rst
